from distutils.core import setup

setup(
    name ='test_dist',
    version = '1.0.0',
    py_modules = ['test_dist'],
    author = 'Kaibo Huang',
    author_email = 'huangkaibochn@gmail.com',
    description = 'test distribution',
)